/*
    UHU-menu -- output plugin for Enlightenment (0.16.5, 0.16.6)
    Copyright (C) 2003  Koblinger Egmont <egmont@uhulinux.hu>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#define _GNU_SOURCE
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <limits.h>
#include <errno.h>
#include <sys/stat.h>

#include "uhu-menu.h"

static void print_name (FILE *f, const char *s)
{
	if (s == NULL) {
		fprintf(f, "-");
		return;
	}
	while (*s != '\0') {
		if (*s == '"') { s++; continue; } /* FIXME */
		fputc(*s++, f);
	}
}

static void print_exec (FILE *f, const char *s)
{
	if (s == NULL) {
		fprintf(f, "false");
		return;
	}
	while (*s != '\0') {
		if (*s == '"') { s++; continue; } /* FIXME */
		if (*s != '%') { fputc(*s++, f); continue; }
		s++;
		if (*s == '%' || *s == '\0') fputc('%', f);
		if (*s != '\0') s++;
	}
}

static void dump (const struct item *item, const char *lang, const char *path, const char *title)
{
	int i;
	char *p;
	char buf[PATH_MAX];
	FILE *f;
	sprintf(buf, "%s.menu", path);
	f = fopen(buf, "w");
	fprintf(f, "\"");
	print_name(f, title);
	fprintf(f, "\"\n");
	for (i = 0; i < item->subitems_nr; i++) {
		fprintf(f, "\"");
		print_name(f, get_value_locale(&item->subitems[i], NULL, "Name", lang));
		fprintf(f, "\" \"\" ");
		if (!item->subitems[i].issubmenu) {
			fprintf(f, "exec \"%s", item->subitems[i].terminal ? "terminal " : "");
			print_exec(f, get_value(&item->subitems[i], NULL, "Exec", lang));
			fprintf(f, "\"\n");
		} else {
			p = strrchr(item->subitems[i].file_name, '/');
			if (p == NULL) p = item->subitems[i].file_name; else p++;
			fprintf(f, "menu \"%s/%s.menu\"\n", path, p);
			mkdir(path, 0777);
			p = strrchr(item->subitems[i].file_name, '/');
			if (p == NULL) p = item->subitems[i].file_name; else p++;
			sprintf(buf, "%s/%s", path, p);
			dump(&item->subitems[i], lang, buf, get_value_locale(&item->subitems[i], NULL, "Name", lang));
		}
	}
	fclose(f);
}

int write_menu_lang (const struct item *item, const char *path,
  const struct language *language)
{
	char *lang;
	char buf[PATH_MAX];

	lang = language->name;
	sprintf(buf, "%s/menu%s%s", path, lang[0] ? "." : "", lang);
	mkdir(buf, 0777);
	empty_dir(buf);
	strcat(buf, "/UHU");

	dump(item, lang, buf, get_value_locale(item, NULL, "Name", lang));
	return 0;
}

